# Developer guide

## Specifications

Generic DBus specifications:

* [D-Bus Tutorial](https://dbus.freedesktop.org/doc/dbus-tutorial.html)
* [D-Bus Specification](https://dbus.freedesktop.org/doc/dbus-specification.html)


## Running from source

```bash
uv run main.py --config config.yaml
```
